DashboardOverridePreset class
Definition for a preset response that can be selected in the desktop management app.
Constructors
- DashboardOverridePreset({required String name, required String? description, required CommonPartialMockzillaHttpResponse response, DashboardOverridePresetType? type})
-
const
Properties
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
final
- response → CommonPartialMockzillaHttpResponse
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → DashboardOverridePresetType?
-
final
Methods
-
copyWith(
{String? name, String? description, CommonPartialMockzillaHttpResponse? response, DashboardOverridePresetType? type}) → DashboardOverridePreset - Returns a new instance of this object with non-null parameters updated.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
covariant DashboardOverridePreset other) → bool -
The equality operator.
override